var AsciiDoc = AsciiDoc || {};

AsciiDoc.Admonitions = class {
	constructor() {
		this.blocktypes = {
			note: {
				icon: "fas fa-fw fa-info-circle",
			},
			tip: {
				icon: "fas fa-fw fa-lightbulb",
			},
			important: {
				icon: "fas fa-fw fa-comment-alt",
			},
			warning: {
				icon: "fas fa-fw fa-exclamation-circle",
			},
			caution: {
				icon: "fas fa-fw fa-exclamation-triangle",
			},
		};
	}

	run_on(node) {
		for (const cls of node.classList) {
			const found = cls.match(/^icon-(.*)/);

			if (!found)
				continue;

			const icon = found[1];
			const type = this.blocktypes[icon];

			if (type == null)
				continue;

			node.classList.forEach(e => {
				node.classList.remove(e);
			});

			for (const cls of type.icon.split(" ")) {
				node.classList.add(cls);
			}
		}
	}

	observe(mutation) {
		if (mutation.target.dataset.faI2svg == undefined)
			return;

		this.run_on(mutation.target);
	}

	run(target) {
		target.querySelectorAll("div.admonitionblock td.icon i").forEach(item => {
			this.run_on(item);
		});
	}
};

AsciiDoc.Controller = class {
	constructor() {
		var observerConfig = {
			childList: true,
			subtree: true,
		};

		this.observer = new MutationObserver((mut) => {
			mut.forEach(mutation => {
				this.observe(mutation);
			});
		});

		this.mutators = [
			new AsciiDoc.Admonitions(),
		];

		this.observer.observe(document, observerConfig);
	}

	observe(mutation) {
		this.mutators.forEach(mutator => {
			mutator.observe(mutation);
		});
	}

	run(target) {
		this.mutators.forEach(mutator => {
			mutator.run(target);
		});
	}
};

document.addEventListener('DOMContentLoaded', (event) => {
	AsciiDoc._ctrl = new AsciiDoc.Controller();
});
